From 21fb3ed0406bea68847cc15a67bcef5b8092a25c Mon Sep 17 00:00:00 2001
From: Steven Murray <Steven.Murray@cern.ch>
Date: Mon, 9 Feb 2015 20:12:05 +0100
Subject: [PATCH] Archive requests are queued by device group and not by tape
 pool

---
 libs/client/ClientAPI.hpp     | 8 ++++----
 libs/client/MockClientAPI.cpp | 2 +-
 libs/client/MockClientAPI.hpp | 8 ++++----
 3 files changed, 9 insertions(+), 9 deletions(-)

diff --git a/libs/client/MockClientAPI.cpp b/libs/client/MockClientAPI.cpp
index 621b443a6b..a2efe08c1f 100644
--- a/libs/client/MockClientAPI.cpp
+++ b/libs/client/MockClientAPI.cpp
@@ -687,7 +687,7 @@ void cta::MockClientAPI::checkUserIsAuthorisedToArchive(
 //------------------------------------------------------------------------------
 std::list<cta::ArchiveJob> cta::MockClientAPI::getArchiveJobs(
   const SecurityIdentity &requester,
-  const std::string &tapePoolName) {
+  const std::string &deviceGroupName) {
   std::list<cta::ArchiveJob> jobs;
   return jobs;
 }
diff --git a/libs/client/ClientAPI.hpp b/libs/client/ClientAPI.hpp
index a1060de792..a9da38cf8e 100644
--- a/libs/client/ClientAPI.hpp
+++ b/libs/client/ClientAPI.hpp
@@ -291,17 +291,17 @@ public:
     const std::string &dst) = 0;
 
   /**
    * Gets the current list of archive jobs associated with the specified tape
    * pool.
    *
    * @param requester The identity of the user requesting the list.
-   * @param tapePoolName The name of the tape pool.
+   * @param deviceGroupName The name of the device groupdevice group.
    * @return The list of jobs sorted by creation time in ascending order
    * (oldest first).
    */
   virtual std::list<ArchiveJob> getArchiveJobs(
     const SecurityIdentity &requester,
-    const std::string &tapePoolName) = 0;
+    const std::string &deviceGroupName) = 0;
 
 }; // class ClientAPI
 
@@ -291,17 +291,17 @@ public:
 
   /**
-   * Gets the current list of archive jobs associated with the specified tape
-   * pool.
+   * Gets the current list of archive jobs associated with the specified device
+   * group.
    *
    * @param requester The identity of the user requesting the list.
diff --git a/libs/client/MockClientAPI.hpp b/libs/client/MockClientAPI.hpp
index 1098152601..5734f3d2c6 100644
--- a/libs/client/MockClientAPI.hpp
+++ b/libs/client/MockClientAPI.hpp
@@ -292,17 +292,17 @@ public:
     const std::string &dst);
 
   /**
    * Gets the current list of archive jobs associated with the specified tape
    * pool.
    *
    * @param requester The identity of the user requesting the list.
-   * @param tapePoolName The name of the tape pool.
+   * @param deviceGroupName The name of the device groupdevice group.
    * @return The list of jobs sorted by creation time in ascending order
    * (oldest first).
    */
   std::list<ArchiveJob> getArchiveJobs(
     const SecurityIdentity &requester,
-    const std::string &tapePoolName);
+    const std::string &deviceGroupName);
 
 protected:
 
@@ -292,17 +292,17 @@ public:
 
   /**
-   * Gets the current list of archive jobs associated with the specified tape
-   * pool.
+   * Gets the current list of archive jobs associated with the specified device
+   * group.
    *
    * @param requester The identity of the user requesting the list.
-- 
GitLab